@@ -153,6 +153,14 @@ int device_info(unsigned major, unsigned minor, char *name, int *hd_id, int *par
       if (part_id) *part_id = 0;            
       return 9;      
 #endif
+
+#ifdef BLOCK_EXT_MAJOR
+    case (BLOCK_EXT_MAJOR):
+      if (name) sprintf(name, "nvme0n%cp%s", "0123456789"[(minor/16)], to_num_(minor));
+      if (hd_id) *hd_id = 400 + minor;
+      if (part_id) *part_id = 0;
+      return 10;
+#endif
   }
   if (name) *name = 0;
   if (hd_id) *hd_id = -1;
@@ -186,9 +194,10 @@ int device_id_from_name(const char *devname__, unsigned *pmajor, unsigned *pmino
 
   if (lstat(devname,&stat_buf)) { BLAHBLAH(1,perror(devname)); return -1; }
   if (S_ISLNK(stat_buf.st_mode)) {
-    char lname[512];
-    int n = readlink(devname, lname, 511); lname[n] = 0;
-    snprintf(devname,512,"/dev/%s",stripdev(lname));
+    devname_ = realpath(devname, NULL);
+    if(!devname_) { BLAHBLAH(1,perror(devname)); return -1; }
+    strncpy(devname, devname_, 512); devname[511] = 0;
+    free(devname_);
     if (stat(devname,&stat_buf)) { BLAHBLAH(1,perror(devname)); return -1; }
   }
   if (!S_ISBLK(stat_buf.st_mode)) {
