@@ -6,17 +6,18 @@
 #ifdef GKRELLM
 #include <gdk/gdk.h>
 #endif
-
+/*
 #ifndef GKRELLM
 #define DOCK_WIDTH 64
 #else
 #define DOCK_WIDTH 60
 #endif
 #define DOCK_HEIGHT DOCK_WIDTH
-
+*/
 typedef struct {
   Display *display;
   Window  normalwin, iconwin, rootwin;
+  int iconwin_mapped, normalwin_mapped;
   Window  win; /* either normalwin or iconwin */
   Visual  *visual;
   Colormap colormap;
@@ -35,6 +36,7 @@ typedef struct {
   int flags; /* combination of DOCKPREF_xxx */
   char *display;
   char *geometry;
+  int  dockapp_size;
 } DockImlib2Prefs;
 
 #define DOCKIMLIB2_VERSION "0.9.0"
