@@ -63,6 +63,8 @@ int hdplop_main(int w, int h, GdkDrawable *gkdrawable);
 void gkrellm_hdplop_update(int update_options);
 #endif
 void change_displayed_hd(int dir);
+void next_displayed_hd();
+void prev_displayed_hd();
 void init_fonts(App*);
 DECL_GLOB_INIT(App *app, NULL);
 #endif
